#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.3.0.0
visibility:           public
id:                   hls-test-utils-2.3.0.0-Cx2gCSyOkF67TYVh9iaPBY
key:                  hls-test-utils-2.3.0.0-Cx2gCSyOkF67TYVh9iaPBY
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b0233678b71a90611a4132a55d788b45
exposed:              True
exposed-modules:      Test.Hls Test.Hls.FileSystem Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.3.0.0-Cx2gCSyOkF67TYVh9iaPBY
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    async-2.2.6-5xQ7XDEe3v3DeLHeJRStgT base-4.18.2.1
    blaze-markup-0.8.3.0-95wdhLC99M6I30rZ5XrQvr bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU
    directory-1.3.8.5 extra-1.7.16-92gEBqN3yIpF5We3DBC4D
    filepath-1.4.300.1 ghcide-2.3.0.0-JSspKOqlahaAwnXaTGGrov
    hls-graph-2.3.0.0-9HjeNoQRHzkHCLPeF94uLn
    hls-plugin-api-2.3.0.0-HSJ5IykGHJrE42B9MfY8EV
    lens-5.3.4-FoS34BQg8yPHQoAczDydbc
    lsp-2.2.0.0-9lJlGvT5rLo8cal3T7PXHz
    lsp-test-0.16.0.0-1Gwu5HV45O16MNq04Aqz4y
    lsp-types-2.0.2.0-43sY9mKjaTf68jRedQkuAz
    row-types-1.0.1.2-IvSEReU7h2Z2Q9S7ubqnHd
    tasty-1.5.3-Exj5fOeuSOhFgSXZfzsDUq
    tasty-expected-failure-0.12.3-Dlb2tFnJyZRGA49jZnt0hx
    tasty-golden-2.3.6-EN3I9xylsy6Cpb6PLiFnUh
    tasty-hunit-0.10.2-Kw5cfkeTKbS2vHBXEHB5Hj
    tasty-rerun-1.1.20-GATNE14r3HiIePdM9JIo93
    temporary-1.3-HWoowl2obdSCRTCICKYJCV text-2.0.2
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

